@@ -1,8 +1,8 @@
 #' convert_fm_d14c
 #'
 #' @description convert fraction modern to d14c and d14c to fraction modern
-#' @param fm fraction modern (default NA)
-#' @param d14c delta 14C in per mille (default NA)
+#' @param fm fraction modern
+#' @param d14c delta 14c in per mille
 #' @param obs_date_y year of observation/sample collection
 #' @param verbose prints message stating which conversion was performed
 #' @author J. Beem-Miller
@@ -18,7 +18,7 @@ convert_fm_d14c <- function(fm = NA, d14c = NA, obs_date_y, verbose = TRUE) {
       message("calculating ", "\u0394", "14C from fraction modern")
     }
     (fm * exp(lambda * (-obs_date_y + 1950)) - 1) * 1000
-  } else {
+  } else if (is.na(fm)) {
     if (verbose) {
       message("calculating fraction modern from ", paste0("\u0394", "14C"))
     }
