@@ -7,7 +7,7 @@ test_that("compile", {
   expect_error(compile(tempdir(), return_type = 1))
   expect_error(compile(tempdir(), checkdoi = 1))
   expect_error(compile(tempdir(), verbose = 1))
-  
+
   # Run example
   database <- ISRaD::Gaudinski_2001
   td <- tempdir()
@@ -15,10 +15,13 @@ test_that("compile", {
   ISRaD.save.xlsx(
     database = database,
     template_file = system.file("extdata", "ISRaD_Master_Template.xlsx", package = "ISRaD"),
-    outfile = outfile)
+    outfile = outfile
+  )
   expect_true(file.exists(outfile))
-  
-  ISRaD.compiled <- compile(td, write_report = TRUE, write_out = TRUE,
-                            return_type = "list", checkdoi = FALSE, verbose = FALSE)
+
+  ISRaD.compiled <- compile(td,
+    write_report = TRUE, write_out = TRUE,
+    return_type = "list", checkdoi = FALSE, verbose = FALSE
+  )
   expect_true(is_israd_database(ISRaD.compiled))
 })
